<?php

use \Model\Admin;
use \Model\User;


class Controller_Admin extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check() || !Auth::member(100))
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));
        View::set_global('business', User::user_business($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

	public function action_index()
	{
		View::set_global('content', 'admin/dashboard');
        View::set_global('dashboard', Admin::dashboard($this->userID));

		return View::forge('index');
	}


    /* === USERS === */

    public function action_all_users()
    {
		View::set_global('content', 'admin/all-users');
        View::set_global('users', Admin::users());

		return View::forge('index');
    }

    public function action_delete_user()
    {
        Admin::delete_user(Uri::segment(3));
        Response::redirect_back();
    }

    /* === END USERS === */


    /* === CATEGORIES === */

    public function action_all_categories()
    {
		View::set_global('content', 'admin/all-categories');
		View::set_global('categories', Admin::categories());

		return View::forge('index');
    }

    public function action_add_category()
    {
        $validation = Validation::forge();
        $validation->add_field('category', 'category', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::create_category($validation->validated('category'));
            Response::redirect_back();
        }
        else
        {
            View::set_global('content', 'admin/all-categories');
            View::set_global('categories', Admin::categories());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_category()
    {
        $validation = Validation::forge();
        $validation->add_field('updateCategory', 'category', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_category($validation->validated('updateCategory'), Input::post('categoryID'));
            Response::redirect('admin/all-categories');
        }
        else
        {
            View::set_global('content', 'admin/all-categories');
            View::set_global('categories', Admin::categories());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_delete_category()
    {
        Admin::delete_category(Uri::segment(3));
		Response::redirect_back();
    }

    /* === END CATEGORIES === */


    /* === SUBCATEGORIES === */

    public function action_all_subcategories()
    {
		View::set_global('content', 'admin/all-subcategories');
        View::set_global('categories', Admin::categories());
        View::set_global('subcategories', Admin::subcategories());

		return View::forge('index');
    }

    public function action_add_subcategory()
    {
        $validation = Validation::forge();
        $validation->add_field('category', 'category', 'required|trim');
        $validation->add_field('subcategory', 'subcategory', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::create_subcategory($validation->validated('category'), $validation->validated('subcategory'));
            Response::redirect_back();
        }
        else
        {
            View::set_global('content', 'admin/all-subcategories');
            View::set_global('categories', Admin::categories());
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_subcategory()
    {
        $validation = Validation::forge();
        $validation->add_field('updateSubcategory', 'subcategory', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_subcategory($validation->validated('updateSubcategory'), Input::post('subcategoryID'));
            Response::redirect('admin/all-subcategories');
        }
        else
        {
            View::set_global('content', 'admin/all-subcategories');
            View::set_global('categories', Admin::categories());
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_delete_subcategory()
    {
        Admin::delete_subcategory(Uri::segment(3));
        Response::redirect('admin/all-subcategories');
    }

    /* === SUBCATEGORIES === */


    /* === ACCOUNT === */

    public function action_change_account()
    {
        View::set_global('content', 'admin/account');

        return View::forge('index');
    }

    public function action_edit_account()
    {
        $validation = Validation::forge();
        $validation->add_field('email', 'E-mail', 'required|trim|valid_email');
        $validation->add_field('remail', 'Repeat E-mail', 'required|trim|valid_email|match_field[email]');

        if ($validation->run() && Input::method() == 'POST')
        {
            Auth::update_user(
                array(
                    'email' => $validation->validated('email'),
                )
            );

            Auth::logout();
            Response::redirect('login');
        }
        else
        {
            View::set_global('content', 'admin/account');
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_password()
    {
        $validation = Validation::forge();
        $validation->add_field('old-password', 'Old Password', 'required|trim|min_length[6]');
        $validation->add_field('new-password', 'New Password', 'required|trim|min_length[6]');

        if ($validation->run() && Input::method() == 'POST')
        {
            try
            {
                Auth::update_user(
                    array(
                        'password'      => $validation->validated('new-password'),
                        'old_password'  => $validation->validated('old-password')
                    )
                );

                Auth::logout();
                Response::redirect('login');
            }
            catch (\SimpleUserWrongPassword $e)
            {
                if ($e->getCode() == 0)
                {
                    Session::set_flash('message', Lang::get('old_password_is_wrong'));
                }
                else
                {
                    Session::set_flash('message', Lang::get('access_denied'));
                }

                Response::redirect_back();
            }
        }
        else
        {
            View::set_global('content', 'admin/account');
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    /* === END ACCOUNT === */


    /* === LANGUAGES === */

    public function action_languages()
    {
		View::set_global('content', 'admin/languages/all');
		View::set_global('languages', Admin::languages());
        View::set_global('countries', Admin::countries());

		return View::forge('index');
    }

    public function action_show_language()
    {
		View::set_global('content', 'admin/languages/edit');
        View::set_global('language', Admin::language(Uri::segment(3)));

        return View::forge('index');
    }

    public function action_add_language()
    {
        $validation = Validation::forge();
        $validation->add_field('language', 'Country', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::create_language($validation->validated('language'));
            Response::redirect_back();
        }
        else
        {
            View::set_global('content', 'admin/languages/all');
            View::set_global('languages', Admin::languages());
            View::set_global('countries', Admin::countries());

            return View::forge('index');
        }
    }

    public function action_edit_language()
    {
        Config::set('language', Input::post('language'));
        $words = Input::post('words');

        foreach ($words as $word => $translate)
        {
            Lang::set('language.' . $word, $translate);
            Lang::save('global', 'language');
        }

        Response::redirect_back();
    }

    public function action_delete_language()
    {
        Admin::delete_language(Uri::segment(3));
        Response::redirect_back();
    }

    /* === END LANGUAGES === */


    /* === SETTINGS === */

    public function action_settings()
    {
		View::set_global('content', 'admin/settings');
        View::set_global('languages', Admin::languages());

		return View::forge('index');
    }

    public function action_edit_app()
    {
        $validation = Validation::forge();
        $validation->add_field('app', 'buton', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_app($validation->validated('app'));
            Response::redirect('admin/settings');
        }
        else
        {
            View::set_global('content', 'admin/settings');
            View::set_global('languages', Admin::languages());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_app_name()
    {
        $validation = Validation::forge();
        $validation->add_field('name', 'buton', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_app_name($validation->validated('name'));
            Response::redirect('admin/settings');
        }
        else
        {
            View::set_global('content', 'admin/settings');
            View::set_global('languages', Admin::languages());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_default_language()
    {
        $validation = Validation::forge();
        $validation->add_field('language', 'language', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_default_language($validation->validated('language'));
            Response::redirect('admin/settings');
        }
        else
        {
            View::set_global('content', 'admin/settings');
            View::set_global('languages', Admin::languages());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_power()
    {
        $validation = Validation::forge();
        $validation->add_field('power', 'power', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            Admin::update_power($validation->validated('power'));
            Response::redirect('admin/settings');
        }
        else
        {
            View::set_global('content', 'admin/settings');
            View::set_global('languages', Admin::languages());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }
    /* === END SETTINGS === */

}












