<?php

use \Model\Admin;
use \Model\Appointment;
use \Model\User;
use \Model\Company;

class Controller_Appointment extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    public function action_new_appointment()
    {
		View::set_global('content', 'user/appointment/new');
        View::set_global('companies', Company::companies($this->userID));

		return View::forge('index');
    }

    public function action_all_appointments()
    {
		View::set_global('content', 'user/appointment/all');
		View::set_global('appointments', Appointment::appointments($this->userID));

		return View::forge('index');
    }

    public function action_create_appointment()
    {
		View::set_global('content', 'user/appointment/appoiment');
        View::set_global('company', Company::company(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_show_appointment()
    {
		View::set_global('content', 'user/appointment/edit');
        View::set_global('appointment', Appointment::appointment(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_add_appointment()
    {
        $validation = Validation::forge();
        $validation->add_field('subject', 'subject', 'required|trim');
        $validation->add_field('startDate', 'start date', 'required|trim|valid_date');
        $validation->add_field('startTime', 'startTime', 'trim|valid_date');
        $validation->add_field('endDate', 'endDate', 'trim|valid_date');
        $validation->add_field('endTime', 'endTime', 'trim|valid_date');
        $validation->add_field('message', 'message', 'trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'subject'   => $validation->validated('subject'),
                'startDate' => $validation->validated('startDate'),
                'startTime' => $validation->validated('startTime'),
                'endDate'   => $validation->validated('endDate'),
                'endTime'   => $validation->validated('endTime'),
                'obs'       => $validation->validated('message')
            );

            Appointment::create_appointment($values, Input::post('companyID'), $this->userID);
            Response::redirect('all-appointments');
        }
        else
        {
            View::set_global('content', 'user/appointment/appoiment');
            View::set_global('company', Company::company(Input::post('companyID'), $this->userID));
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_appointment()
    {
        $validation = Validation::forge();
        $validation->add_field('subject', 'subject', 'required|trim');
        $validation->add_field('startDate', 'start date', 'required|trim|valid_date');
        $validation->add_field('startTime', 'startTime', 'trim');
        $validation->add_field('endDate', 'endDate', 'trim');
        $validation->add_field('endTime', 'endTime', 'trim');
        $validation->add_field('message', 'message', 'trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'subject'   => $validation->validated('subject'),
                'startDate' => $validation->validated('startDate'),
                'startTime' => $validation->validated('startTime'),
                'endDate'   => $validation->validated('endDate'),
                'endTime'   => $validation->validated('endTime'),
                'obs'       => $validation->validated('message')
            );

            Appointment::update_appointment($values, Input::post('appointmentID'), $this->userID);
            Response::redirect('all-appointments');
        }
        else
        {
            View::set_global('content', 'user/appointment/appoiment');
            View::set_global('appointment', Appointment::appointment(Input::post('appointmentID'), $this->userID));
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_complete_appointment()
    {
		Appointment::complete_appointment(Uri::segment(2), $this->userID);
        Response::redirect('all-appointments');
    }

    public function action_delete_appointment()
    {
		Appointment::delete_appointment(Uri::segment(2), $this->userID);
        Response::redirect('all-appointments');
    }

    public function action_settings()
    {
		View::set_global('content', 'user/appointment/settings');

		return View::forge('index');
    }
}
