<?php

use \Model\Admin;
use \Model\Company;
use \Model\User;

class Controller_Company extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    public function action_new_company()
    {
		View::set_global('content', 'user/company/new');
        View::set_global('subcategories', Admin::subcategories());

		return View::forge('index');
    }

    public function action_all_companies()
    {
		View::set_global('content', 'user/company/all');
        View::set_global('companies', Company::companies($this->userID));

		return View::forge('index');
    }

    public function action_show_company()
    {
		View::set_global('content', 'user/company/edit');
        View::set_global('subcategories', Admin::subcategories());
        View::set_global('company', Company::company(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_add_company()
    {
        $validation = Validation::forge();
        $validation->add_field('category', 'category', 'required|trim');
        $validation->add_field('name', 'name', 'required|trim');
        $validation->add_field('country', 'country', 'required|trim');
        $validation->add_field('state', 'state', 'required|trim');
        $validation->add_field('city', 'city', 'required|trim');
        $validation->add_field('zip', 'zip code', 'required|trim');
        $validation->add_field('address', 'address', 'required|trim');
        $validation->add_field('phone', 'phone', 'required|trim');
        $validation->add_field('email', 'email', 'required|trim');
        $validation->add_field('website', 'website', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'category'      => $validation->validated('category'),
                'name'          => $validation->validated('name'),
                'country'       => $validation->validated('country'),
                'state'         => $validation->validated('state'),
                'city'          => $validation->validated('city'),
                'zip'           => $validation->validated('zip'),
                'address'       => $validation->validated('address'),
                'phone'         => $validation->validated('phone'),
                'email'         => $validation->validated('email'),
                'website'       => Input::post('website'),
                'description'   => Input::post('description')
            );

            Company::create_company($values, $this->userID);
            Response::redirect('all-companies');
        }
        else
        {
            View::set_global('content', 'user/company/new');
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_company()
    {
        $validation = Validation::forge();
        $validation->add_field('category', 'category', 'required|trim');
        $validation->add_field('name', 'name', 'required|trim');
        $validation->add_field('country', 'country', 'required|trim');
        $validation->add_field('state', 'state', 'required|trim');
        $validation->add_field('city', 'city', 'required|trim');
        $validation->add_field('zip', 'zip code', 'required|trim');
        $validation->add_field('address', 'address', 'required|trim');
        $validation->add_field('phone', 'phone', 'required|trim');
        $validation->add_field('email', 'email', 'required|trim');
        $validation->add_field('website', 'website', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'category'      => $validation->validated('category'),
                'name'          => $validation->validated('name'),
                'country'       => $validation->validated('country'),
                'state'         => $validation->validated('state'),
                'city'          => $validation->validated('city'),
                'zip'           => $validation->validated('zip'),
                'address'       => $validation->validated('address'),
                'phone'         => $validation->validated('phone'),
                'email'         => $validation->validated('email'),
                'website'       => Input::post('website'),
                'description'   => Input::post('description')
            );

            Company::update_company($values, Input::post('companyID'), $this->userID);
            Response::redirect('all-companies');
        }
        else
        {
            View::set_global('content', 'user/company/edit');
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('company', Company::company(Input::post('compnay_id'), $this->userID));
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_delete_company()
    {
        Company::delete_company(Uri::segment(2), $this->userID);
        Response::redirect('all-companies');
    }

}