<?php

use \Model\Admin;
use \Model\User;
use \Email;
use \Security;

class Controller_Login extends Controller
{

    public function before()
    {
        parent::before();

        View::set_global('base', Uri::base());
        View::set_global('title', 'SOCIAL BUSINESS CONTACTS');

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('contacts', Admin::contacts());

        Config::set('language', $adminSettings['app_language']);
        Lang::load('global');
    }

    /* === LOGIN === */

    public function action_login()
    {
        $validation = Validation::forge();
        $validation->add_field('email', 'E-mail', 'required|trim|valid_email');
        $validation->add_field('password', 'Password', 'required|trim|min_length[6]');

        if ($validation->run() && Input::method() == 'POST')
        {
            if ( ! \Security::check_token())
            {
                Session::set_flash('message', Lang::get('csrf_validation_failed_possible_hacking_attempt_detected'));
                Response::redirect('login');
            }
            else
            {
                if(Auth::login(Input::post('email'), Input::post('password')))
                {
                    if (Auth::member(100))
                    {
                        Response::redirect('admin');
                    }

                    $admin = Admin::settings();
                    if (Auth::member(1))
                    {
                        Response::redirect('user');
                    }

                    Response::redirect('login');
                }
                else
                {
                    Session::set_flash('message', Lang::get('wrong_user_or_password'));
                    Response::redirect('login');
                }
            }
        }
        else
        {
            $data['errors'] = $validation->error();

            return View::forge('login/login', $data)->render();
        }
    }

    /* === END LOGIN === */


    /* === REGISTRATION === */

    public function action_registration()
    {
        $validation = Validation::forge('registerform');
        $validation->add_field('remail', 'E-mail', 'required|trim|valid_email');
        $validation->add_field('rrepeat', 'Repeat E-mail', 'required|trim|valid_email|match_field[remail]');
        $validation->add_field('rpassword', 'Password', 'required|trim|min_length[6]');

        if ($validation->run() && Input::method() == 'POST')
        {
            if ( ! \Security::check_token())
            {
                Session::set_flash('message', Lang::get('csrf_validation_failed_possible_hacking_attempt_detected'));
                Response::redirect('login');
            }
            else
            {
                try
                {
                    Auth::create_user(
                        $validation->validated('remail'),
                        $validation->validated('rpassword'),
                        $validation->validated('remail'),
                        1,
                        array(
                            'fullname' => 'A. New User',
                        )
                    );

                    $user   = \DB::select_array(\Config::get('simpleauth.table_columns', array('*')))
                            ->where('email', '=', $validation->validated('remail'))
                            ->from(\Config::get('simpleauth.table_name'))
                            ->as_object()->execute(\Config::get('simpleauth.db_connection'))->current();

                    User::create_user($user->id);

                    Session::set_flash('message', Lang::get('account_successfully_created_use_your_details_to_authenticate'));
                    Response::redirect('login');
                }
                catch (\SimpleUserUpdateException $e)
                {
                    if ($e->getCode() == 2)
                    {
                        Session::set_flash('message', Lang::get('email_already_exists'));
                    }
                    else
                    {
                        Session::set_flash('message', Lang::get('access_denied'));
                    }

                    Response::redirect_back();
                }
            }
        }
        else
        {
            $data['errors'] = $validation->error();

            return View::forge('login/login', $data)->render();
        }
    }

    /* === END REGISTRATION === */


    /* === PASSWORD === */

    public function action_lost()
    {
        View::set_global('title', 'lost password');

        return View::forge('login/lost-password')->render();
    }

    public function action_new_password()
    {
        $validation = Validation::forge();
        $validation->add_field('email', 'E-mail', 'required|trim|valid_email');

        if ($validation->run() && Input::method() == 'POST')
        {
            if ( ! \Security::check_token())
            {
                Session::set_flash('message', Lang::get('csrf_validation_failed_possible_hacking_attempt_detected'));
                Response::redirect('login');
            }
            else
            {
                $user = User::user_by_email($validation->validated('email'));

                if($user)
                {
                    $new_pass   = Auth::reset_password($user->username);
                    $admin      = Admin::settings();

                    \Package::load('email');
                    $email = Email::forge();
                    $email->html_body(
                        \View::forge('login/email')
                        ->set('password', $new_pass)
                        ->render()
                    );

                    $email->subject('New password from ' . $admin['app_name']);
                    $email->from($admin['app_email'], 'Admin ' . $admin['app_name']);
                    $email->to($user->email);

                    try
                    {
                        $email->send();
                    }
                    catch(\EmailValidationFailedException $e)
                    {
                        echo "error 1";
                    }
                    catch(\EmailSendingFailedException $e)
                    {
                        echo "error 2";
                    }

                    Session::set_flash('message', Lang::get('a_new_password_has_been_sent_to_your_email'));
                    Response::redirect_back();
                }
                else
                {
                    $data['errors'] = array('email' => 'This email address does not exist !');

                    return View::forge('login/lost-password', $data)->render();
                }
            }
        }
        else
        {
            $data['errors'] = $validation->error();

            return View::forge('login/lost-password', $data)->render();
        }
    }

    /* === END PASSWORD === */


    /* === LOGOUT === */

    public function action_logout()
    {
        Auth::logout();
        Response::redirect();
    }

    /* === END LOGOUT === */

}