<?php

use \Model\Admin;
use \Model\Message;
use \Model\User;

class Controller_Message extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    public function action_inbox()
    {
		View::set_global('content', 'user/message/inbox');
		View::set_global('messages', Message::messages($this->userID, true));

		return View::forge('index');
    }

    public function action_all_send()
    {
		View::set_global('content', 'user/message/send');
		View::set_global('messages', Message::messages($this->userID, false));

		return View::forge('index');
    }

    public function action_send_message()
    {
        $validation = Validation::forge();
        $validation->add_field('subject', 'subject', 'required|trim');
        $validation->add_field('message', 'message', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'subject'   => $validation->validated('subject'),
                'text'      => $validation->validated('message')
            );

            if (Input::post('messageID'))
            {
                Message::read_message(Input::post('messageID'), $this->userID);
            }

            Message::create_message($values, Input::post('userID'), $this->userID);
            Session::set_flash('message', Lang::get('your_message_has_been_sent'));
            Response::redirect('dashboard');
        }
        else
        {
            $userID = false;

            if ( Input::method() == 'POST')
            {
                $userID = Input::post('userID');
            }

            if(!$userID)
            {
                Session::set_flash('message', Lang::get('this_user_is_not_found'));
                Response::redirect('dashboard');
            }

            View::set_global('content', 'user/page/index');
            View::set_global('left', false);

            View::set_global('business', User::user_business($userID));
            View::set_global('userSocials', User::user_socials($userID));

            View::set_global('sliderLogo', User::user_slider_logo($userID));
            View::set_global('portfolio', false);
            View::set_global('partners', false);

            View::set_global('status', User::user_partner_status($userID, $this->userID));
            View::set_global('showDashboard', true);

            View::set_global('user', false);
            if ($userID == $this->userID)
            {
                View::set_global('user', true);
            }

            View::set_global('page', 'send-message');

            View::set_global('errors', $validation->error());
            return View::forge('index');
        }
    }

    public function action_read_message()
    {
        Message::read_message(Uri::segment(2), $this->userID);
		Response::redirect('inbox');
    }

    public function action_show_message()
    {
		View::set_global('content', 'user/message/message');
		View::set_global('message', Message::message(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_delete_message()
    {
        Message::delete_message(Uri::segment(2), $this->userID);
		Response::redirect('inbox');
    }

}
