<?php

use \Model\Admin;
use \Model\Newsletter;
use \Model\User;
use \Email;

class Controller_Newsletter extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    /* === NEWSLETTER === */

    public function action_new_newsletter()
    {
		View::set_global('content', 'user/newsletter/new');

		return View::forge('index');
    }

    public function action_all_newsletters()
    {
		View::set_global('content', 'user/newsletter/all');
		View::set_global('newsletters', Newsletter::newsletters($this->userID));

		return View::forge('index');
    }

    public function action_add_newsletter()
    {
        $validation = Validation::forge();
        $validation->add_field('subject', 'subject', 'required|trim');
        $validation->add_field('message', 'message', 'required|trim');
        $validation->add_field('send', 'send newsletter to', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'subject'   => $validation->validated('subject'),
                'message'   => $validation->validated('message'),
                'send'      => $validation->validated('send')
            );

            $emails = Newsletter::emails($validation->validated('send'), $this->userID);

            if ($emails)
            {
                Newsletter::create_newsletter($values, $this->userID);
                $admin  = Admin::settings();

                \Package::load('email');
                $email = Email::forge();
                $email->html_body(
                    \View::forge('_module/newsletter')
                    ->set('app',        $admin['app_name'])
                    ->set('subject',    $validation->validated('subject'))
                    ->set('content',    $validation->validated('message'))
                    ->render()
                );

                $email->subject('Newsletter from ' . $admin['app_name']);
                $email->from($admin['app_email'], 'Admin ' . $admin['app_name']);
                $email->to($emails);

                try
                {
                    $email->send();
                    Session::set_flash('message', Lang::get('newsletter_send'));
                }
                catch(\EmailValidationFailedException $e)
                {
                    Session::set_flash('message', Lang::get('error_1'));
                }
                catch(\EmailSendingFailedException $e)
                {
                    Session::set_flash('message', Lang::get('error_2'));
                }
            }
            else
            {
                Session::set_flash('message', Lang::get('no_partners_or_subcribers'));
                Response::redirect_back();
            }

            Response::redirect('dashboard');
        }
        else
        {
            View::set_global('content', 'user/newsletter/new');
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_show_newsletter()
    {
		View::set_global('content', 'user/newsletter/newsletter');
		View::set_global('newsletter', Newsletter::newsletter(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_delete_newsletter()
    {
        Newsletter::delete_newsletter(Uri::segment(2), $this->userID);
        Response::redirect('all-newsletters');
    }

    /* === END NEWSLETTER === */


    /* === SUBSCRIBERS === */

    public function action_all_subscribers()
    {
		View::set_global('content', 'user/newsletter/subscribers');
        View::set_global('subscribers', Newsletter::subscribers($this->userID));

		return View::forge('index');
    }

    public function action_add_subscriber()
    {
        $validation = Validation::forge();
        $validation->add_field('subscribe', 'subscribe', 'required|trim|valid_email');

        if ($validation->run() && Input::method() == 'POST')
        {
            if (!Newsletter::exists_subscriber($validation->validated('subscribe'), Input::post('userID')))
            {
                Newsletter::create_subscriber($validation->validated('subscribe'), Input::post('userID'));
                Session::set_flash('message', Lang::get('you_were_added_to_our_data_base_thank_you'));
            }
            else
            {
                Session::set_flash('message', Lang::get('you_are_already_registered_to_our_database'));
            }

            Response::redirect_back();
        }
        else
        {
            $userID = false;

            if ( Input::method() == 'POST')
            {
                $userID = Input::post('userID');
            }

            if(!$userID)
            {
                Session::set_flash('message', Lang::get('this_user_is_not_found'));
                Response::redirect('dashboard');
            }

            View::set_global('content', 'user/page/index');
            View::set_global('left', false);

            View::set_global('business', User::user_business($userID));
            View::set_global('userSocials', User::user_socials($userID));
            View::set_global('pageSettings', User::user_settings($userID, true));

            View::set_global('sliderLogo', User::user_slider_logo($userID));
            View::set_global('likes', User::likes($userID));
            View::set_global('portfolio', false);
            View::set_global('partners', false);

            View::set_global('status', User::user_partner_status($userID, $this->userID));
            View::set_global('showDashboard', true);

            View::set_global('user', false);
            if ($userID == $this->userID)
            {
                View::set_global('user', true);
            }

            View::set_global('page', 'about-us');

            View::set_global('errors', $validation->error());
            return View::forge('index');
        }
    }

    public function action_delete_subscriber()
    {
        Newsletter::delete_subscriber(Uri::segment(2), $this->userID);
        Response::redirect('all-subscribers');
    }

    /* === END SUBSCRIBERS === */

}
