<?php

use \Model\Admin;
use \Model\Timeline;
use \Model\User;

class Controller_Timeline extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    public function action_new_timeline()
    {
		View::set_global('content', 'user/timeline/new');

		return View::forge('index');
    }

    public function action_all_timeline()
    {
		View::set_global('content', 'user/timeline/all');
		View::set_global('timeline', Timeline::timeline($this->userID));

		return View::forge('index');
    }

    public function action_view_timeline()
    {
		View::set_global('content', 'user/timeline/timeline');
		View::set_global('timeline', Timeline::details(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_show_timeline()
    {
		View::set_global('content', 'user/timeline/edit');
		View::set_global('timeline', Timeline::one(Uri::segment(2), $this->userID));

		return View::forge('index');
    }

    public function action_add_timeline()
    {
        $validation = Validation::forge();
        $validation->add_field('title', 'title', 'required|trim');
        $validation->add_field('description', 'description', 'trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'title' => $validation->validated('title'),
                'text'  => $validation->validated('description')
            );

            Timeline::create_timeline($values, $this->userID);
            Response::redirect('all-timeline');
        }
        else
        {
            View::set_global('content', 'user/timeline/new');
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_edit_timeline()
    {
        $validation = Validation::forge();
        $validation->add_field('title', 'title', 'required|trim');
        $validation->add_field('description', 'description', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'title' => $validation->validated('title'),
                'text'  => $validation->validated('description')
            );

            Timeline::update_timeline($values, Input::post('timelineID'), $this->userID);
            Response::redirect('all-timeline');
        }
        else
        {
            View::set_global('content', 'user/timeline/edit');
            View::set_global('timeline', Timeline::one(Input::post('timelineID'), $this->userID));
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_delete_timeline()
    {
        Timeline::delete_timeline(Uri::segment(2), $this->userID);
        Response::redirect('all-timeline');
    }

    /* === COMMENTS === */

    public function action_ajax_send_comment()
    {
        $validation = Validation::forge();
        $validation->add_field('comment', 'comment', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            View::set_global('comment', Timeline::create_comment(Input::post('timelineID'), Input::post('userID'), $this->userID, $validation->validated('comment')));
            return View::forge('user/page/ajax_comment');
        }
        else
        {
            View::set_global('content', 'user/timeline/edit');
            View::set_global('timeline', Timeline::one(Input::post('timelineID'), $this->userID));
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_ajax_edit_comment()
    {
        $validation = Validation::forge();
        $validation->add_field('content', 'comment', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            $ids = Input::post('data');
            Timeline::update_comment($validation->validated('content'), $ids['timelineID'], $ids['commentID'], $this->userID);
        }
        else
        {
            Response::redirect_back();
        }
    }

    public function action_ajax_delete_comment()
    {
        Timeline::delete_comment(Input::post('commentID'), $this->userID);
    }
    /* === END COMMENTS === */
}

