<?php

use \Model\Admin;
use \Model\User;
use \Model\Company;
use \Model\Timeline;

class Controller_User extends Controller
{

    private $userID;

    public function before()
    {
        parent::before();

        if(!Auth::check())
        {
            Response::redirect('login/logout');
        }

        $user           = Auth::get_user_id();
        $this->userID   = $user[1];

        View::set_global('base', Uri::base());
        View::set_global('title', str_replace('-',' ', Uri::segment(1)));
        View::set_global('left', true);

        $userSettings = User::user_settings($this->userID, false);
        View::set_global('userSettings', $userSettings);
        View::set_global('userNow', User::user_now($this->userID));
        View::set_global('business', User::user_business($this->userID));

        $adminSettings = Admin::settings();
        View::set_global('settings', $adminSettings);
        View::set_global('admin', Auth::member(100) ? true : false);

        Config::set('language', $adminSettings['app_language']);

        if ($userSettings['country_name'])
        {
            Config::set('language', $userSettings['country_name']);
        }

        Lang::load('global');
    }

    public function action_index()
    {
		View::set_global('content', 'user/dashboard');
        View::set_global('dashboard', User::dashboard($this->userID));

		return View::forge('index');
    }

    public function action_dashboard()
    {
		View::set_global('content', 'user/dashboard');
        View::set_global('dashboard', User::dashboard($this->userID));

		return View::forge('index');
    }

    public function action_business()
    {
		View::set_global('content', 'user/my-business');
        View::set_global('subcategories', Admin::subcategories());
        View::set_global('businessCategory', User::business_category($this->userID));

		return View::forge('index');
    }

    public function action_edit_business()
    {
        $validation = Validation::forge();
        $validation->add_field('category', 'category', 'required|trim');
        $validation->add_field('name', 'name', 'required|trim');
        $validation->add_field('country', 'country', 'required|trim');
        $validation->add_field('state', 'state', 'required|trim');
        $validation->add_field('city', 'city', 'required|trim');
        $validation->add_field('zip', 'zip code', 'required|trim');
        $validation->add_field('address', 'address', 'required|trim');
        $validation->add_field('phone', 'phone', 'required|trim');
        $validation->add_field('email', 'email', 'required|trim|valid_email');

        if ($validation->run() && Input::method() == 'POST')
        {
            $values = array(
                'category'      => $validation->validated('category'),
                'name'          => $validation->validated('name'),
                'country'       => $validation->validated('country'),
                'state'         => $validation->validated('state'),
                'city'          => $validation->validated('city'),
                'zip'           => $validation->validated('zip'),
                'address'       => $validation->validated('address'),
                'phone'         => $validation->validated('phone'),
                'email'         => $validation->validated('email'),
                'website'       => Input::post('website'),
                'description'   => Input::post('description')
            );

            User::update_business($values, $this->userID);
            Response::redirect('my-business');
        }
        else
        {
            View::set_global('content', 'user/my-business');
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('businessCategory', User::business_category($this->userID));
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }


    /* === SLIDERS & LOGO & === */

    public function action_cover()
    {
		View::set_global('content', 'user/cover');
        View::set_global('userSocials', User::user_socials($this->userID));
        View::set_global('sliderLogo', User::user_slider_logo($this->userID));

		return View::forge('index');
    }

    public function action_portfolio()
    {
		View::set_global('content', 'user/portfolio');
        View::set_global('portfolio', User::user_portfolio($this->userID));

		return View::forge('index');
    }

    public function action_upload()
    {
        $path       = Uri::segment(2);
        $image      = new SolsoImage();
        $image->set_path(DOCROOT . DS . 'public/upload/' . $path);

        switch($path)
        {
            case 'logo':
                $type   = 1;
                $resize = array(
                    'width'     => 200,
                    'height'    => 200
                );
            break;
            case 'slider':
                $type   = 2;
                $resize = array(
                    'width'     => 1150,
                    'height'    => 350
                );
            break;
            case 'portfolio':
                $type   = 3;
                $resize = array(
                    'width'     => 253,
                    'height'    => 200
                );
            break;
        }

        if ($_FILES['file']['error'] == 0)
        {
            if ($image->complete($_FILES['file']))
            {
                $image->createTthumbs($_FILES['file'], $resize);
                User::upload_image($image->nameOfFiles($_FILES), $this->userID, $type);
                Session::set_flash('message', Lang::get('your_image_was_uploaded'));
            }
            else
            {
                Session::set_flash('message', Lang::get('upload_error'));
            }
        }
        else
        {
            Session::set_flash('message', Lang::get('your_file_is_empty'));
        }

        Response::redirect_back();
    }

    public function action_delete_image()
    {
        User::delete_image($this->userID, Uri::segment(2));
        Response::redirect_back();
    }

    /* === END SLIDERS & LOGO === */


    /* === SOCIALS === */

    public function action_socials()
    {
		View::set_global('content', 'user/socials');
        View::set_global('userSocials', User::user_socials($this->userID));

		return View::forge('index');
    }

    public function action_add_social()
    {
        $validation = Validation::forge();
        $validation->add_field('social', 'social', 'required|trim|valid_url');

        if ($validation->run() && Input::method() == 'POST')
        {
            User::create_social($validation->validated('social'), Input::post('socialID'), $this->userID);
            Response::redirect('my-socials');
        }
        else
        {
            View::set_global('content', 'user/socials');
            View::set_global('userSocials', User::user_socials($this->userID));

            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    /* === END SOCIALS === */


    /* === PASSWORD === */

    public function action_change_password()
    {
		View::set_global('content', 'user/new-password');

		return View::forge('index');
    }

    public function action_edit_password()
    {
        $validation = Validation::forge();
        $validation->add_field('old-password', 'Old Password', 'required|trim|min_length[6]');
        $validation->add_field('new-password', 'New Password', 'required|trim|min_length[6]');

        if ($validation->run() && Input::method() == 'POST')
        {
            try
            {
                Auth::update_user(
                    array(
                        'password'      => $validation->validated('new-password'),
                        'old_password'  => $validation->validated('old-password')
                    )
                );

                Auth::logout();
                Response::redirect('login');
            }
            catch (\SimpleUserWrongPassword $e)
            {
                if ($e->getCode() == 0)
                {
                    Session::set_flash('message', Lang::get('old_password_is_wrong'));
                }
                else
                {
                    Session::set_flash('message', Lang::get('access_denied'));
                }

                Response::redirect_back();
            }
        }
        else
        {
            View::set_global('content', 'user/new-password');
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    /* === END PASSWORD === */


    /* === PARTNER === */

    public function action_all_partners()
    {
		View::set_global('content', 'user/partners');
        View::set_global('partners', User::user_partners($this->userID));

		return View::forge('index');
    }

    public function action_ajax_add_partner()
    {
        User::create_partner(Input::post('partnerID'), $this->userID);
    }

    public function action_ajax_cancel_partner()
    {
        User::cancel_partner(Input::post('partnerID'), $this->userID);
    }

    public function action_ajax_accept_partner()
    {
        User::accept_partner(Input::post('partnerID'), $this->userID);
        $nr = User::user_now($this->userID);
        return json_encode($nr['requests']);
    }

    public function action_ajax_delete_partner()
    {
        User::delete_partner(Input::post('partnerID'), $this->userID);
        $nr = User::user_now($this->userID);
        return json_encode($nr['requests']);
    }

    public function action_requests()
    {
		View::set_global('content', 'user/requests');
        View::set_global('userRequests', User::user_all_requests($this->userID));

		return View::forge('index');
    }

    /* === END PARTNER === */


    /* === PAGE === */

    public function action_ajax_check_name()
    {
        return json_encode(User::check_page_name(Input::post('pageName'), $this->userID));
    }

    public function action_page()
    {
        $userID = $this->userID;

        if (Input::method() == 'POST')
        {
            $userID = Input::post('userID');
        }
        else
        {
            $search = User::user_by_url(Uri::segment(1));

            if ($search)
            {
                $userID = $search->user_id;
            }
        }

        if(!$userID)
        {
            Session::set_flash('message', Lang::get('this_user_is_not_found'));

            if (Auth::member(100))
            {
                Response::redirect('admin');
            }

            Response::redirect('dashboard');
        }

		View::set_global('content', 'user/page/index');
        View::set_global('left', false);

        View::set_global('business', User::user_business($userID));
        View::set_global('userSocials', User::user_socials($userID));
        View::set_global('pageSettings', User::user_settings($userID, true));
        View::set_global('sliderLogo', User::user_slider_logo($userID));
        View::set_global('likes', User::likes($userID));
        View::set_global('portfolio', User::user_portfolio($userID));
        View::set_global('partners', User::user_partners($userID));
        View::set_global('timeline', Timeline::timeline($userID));
        View::set_global('status', User::user_partner_status($userID, $this->userID));
        View::set_global('showDashboard', true);

        View::set_global('user', false);
        if ($userID == $this->userID)
        {
            View::set_global('user', true);
        }

        View::set_global('page', 'about-us');
        if (Uri::segment(2))
        {
            View::set_global('page', Uri::segment(2));
        }

		return View::forge('index');
    }

    public function action_edit_page()
    {
        $validation = Validation::forge();
        $validation->add_field('page', 'page', 'required|trim|valid_string[alpha,numeric,dashes]');

        if ($validation->run() && Input::method() == 'POST')
        {
            $page = User::check_page_name($validation->validated('page'), $this->userID);

            if ($page['results'] == 1 && !$page['user'])
            {
                Session::set_flash('message', Lang::get('page_name_not_available'));
                Response::redirect_back();
            }
            elseif ($page['results'] == 1 && $page['user'])
            {
                Session::set_flash('message', Lang::get('this_is_your_page'));
                Response::redirect_back();
            }
            else
            {
                User::update_page_name($validation->validated('page'), $this->userID);
                Response::redirect('my-business');
            }
        }
        else
        {
            View::set_global('content', 'user/my-business');
            View::set_global('subcategories', Admin::subcategories());
            View::set_global('businessCategory', User::business_category($this->userID));
            View::set_global('validation', $validation->validated());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    /* === END PAGE === */


    /* === WALL === */

    public function action_wall()
    {
		View::set_global('content', 'user/wall');
        View::set_global('left', false);
        View::set_global('wall', User::wall($this->userID));

		return View::forge('index');
    }

    /* === END WALL === */


    /* === SEARCH === */

    public function action_ajax_search()
    {
        return json_encode(User::search(Input::post('query')));
    }

    public function action_more_results()
    {
		View::set_global('content', 'user/results');
        View::set_global('results', User::search(Uri::segment(2)));

		return View::forge('index');
    }
    /* === END SEARCH === */


    /* === SETTINGS === */

    public function action_settings()
    {
		View::set_global('content', 'user/settings');
        View::set_global('languages', Admin::languages());

		return View::forge('index');
    }

    public function action_choose_language()
    {
        $validation = Validation::forge();
        $validation->add_field('language', 'language', 'required|trim');

        if ($validation->run() && Input::method() == 'POST')
        {
            User::update_user_language($validation->validated('language'), $this->userID);

            if (Auth::member(100))
            {
                Response::redirect('admin');
            }

            Response::redirect('dashboard');
        }
        else
        {
            View::set_global('content', 'user/settings');
            View::set_global('languages', Admin::languages());
            View::set_global('errors', $validation->error());

            return View::forge('index');
        }
    }

    public function action_set_privacy()
    {
        User::update_user_privacy(Input::post(), $this->userID);
        Response::redirect_back();
    }

    /* === END SETTINGS === */


    /* === LIKE === */

    public function action_ajax_like()
    {
        User::create_like(Input::post('pageID'), $this->userID);
        return json_encode(User::likes(Input::post('pageID')));
    }
    /* === END LIKE === */

}
