<?php
/**
 *--------------------------------------------------------------------------
 * === CLASS SolsoImage ===
 *--------------------------------------------------------------------------
 * Image Manipulation class using GD/GD2
 *
 * PHP version 5.3
 *
 */
class SolsoImage
{

    private $_uploadPath;
    private $_uploadThummbs;
    private $_filesType     = array ('jpg', 'jpeg', 'jpe', 'png', 'bmp', 'gif');
    private $_maxFileSize   = 2000000;
    private $_prefix;
    private $_sufix;
    private $_text;
    public  $messageErrors = array();


    public function __construct()
    {
        $this->_text     = 'error';
        $this->_prefix   = '<p>';
        $this->_sufix    = '</p>';
    }

    public function set_path($path)
    {
        $this->_uploadPath      = $path . '/';
        $this->_uploadThummbs   = $path . '/thumbs/';    
    }
    
    public function complete($files)
    {
        $validate = array(
            'errors'    => '_checkErrors',
            'extension' => '_checkExtension',
            'max_size'  => '_checkMaxSize'
        );

        foreach ($validate as $name => $value) {
            $errors[$name][] = $this->$value($files);
        }

        if ($this->_checkForErrors($errors)) {
            if ($this->_uploadFile($files)) {
                return true;
            } else {
                $errors['upload'][] = $this->_uploadFile($files);
            }
        }

        foreach ($errors as $name => $valid) {
            foreach ($valid as $message) {
                if ($message == 1) {
                    unset($errors[$name]);
                }
            }
        }
        $this->messageErrors = $errors;
    }

    public function nameOfFiles($files)
    {
        foreach ($files as $file) {
            $filesName[] = $this->_pictureName($file['name']);
        }
        return $filesName;
    }

    public function createTthumbs($files, $newSize = array())
    {
        $source         = $this->_uploadPath . $this->_pictureName($files['name']);
        $destination    = $this->_uploadThummbs . $this->_pictureName($files['name']);
        $size           = getimagesize($source);
        $originalWidth  = $size[0];
        $originalHeight = $size[1];
       
        // $thumbsWidth    = $originalWidth >= $newSize['width'] ? $newSize['width'] : $originalWidth;
        // $thumbsHeight   = floor($originalHeight * ($thumbsWidth / $originalWidth));        
        $thumbsWidth    = $newSize['width'];
        $thumbsHeight   = $newSize['height'];
        $extension      = strtolower(pathinfo($files['name'], PATHINFO_EXTENSION));

        $tempImage      = imagecreatetruecolor($thumbsWidth, $thumbsHeight);
        imagealphablending($tempImage, false);
        imagesavealpha($tempImage, true);
        $transparentindex = imagecolorallocatealpha($tempImage, 255, 255, 255, 127);
        imagefill($tempImage, 0, 0, $transparentindex);        
        
        if ( $extension == 'jpg' || $extension == 'jpeg' || $extension == 'jpe') {
            $image = imagecreatefromjpeg($source);
        }

        if ($extension == 'gif') {
            $image = imagecreatefromgif($source);
        }

        if ($extension == 'png') {
            $image = imagecreatefrompng($source);
        }

        if ($extension == 'bmp') {
            $image = imagecreatefromwbmp($source);
        }

        imagecopyresampled($tempImage, $image, 0, 0, 0, 0, $thumbsWidth, $thumbsHeight, $originalWidth, $originalHeight);

        if ($extension == 'jpg' || $extension == 'jpeg' || $extension == 'jpe') {
            imagejpeg($tempImage, $destination);
        }

        if ($extension == 'gif') {
            imagegif($tempImage, $destination);
        }

        if ($extension == 'png' || $extension == 'bmp') {
            imagepng($tempImage, $destination);
        }

        imagedestroy($tempImage);
    }

    private function _pictureName($name)
    {
        return strtolower($_SESSION['image'] . '_' . str_replace(' ', '_', $name));
    }

    private function _checkForErrors($array)
    {
        foreach ($array as $values) {
            foreach ($values as $valid) {
                if ($valid !== true) {
                    return false;
                }
            }
        }
        return true;
    }

    private function _checkErrors($files)
    {
        if (is_array($files['error'])) {
            if (array_sum($files['error']) == 0) {
                return true;
            }
        } else {
            if ($files['error'] == 0) {
                return true;
            }
        }
        return $this->_prefix . $this->_text['upload_errors'] . $this->_sufix;
    }

    private function _checkExtension($files)
    {
        if (is_array($files['name'])) {
            foreach ($files['name'] as $name) {
                if (!in_array(strtolower(pathinfo($name, PATHINFO_EXTENSION)), $this->_filesType)) {
                    return $this->_prefix . $this->_text['upload_ext'] . $this->_sufix;
                }
            }
        } else {
            if (!in_array(strtolower(pathinfo($files['name'], PATHINFO_EXTENSION)), $this->_filesType)) {
                return $this->_prefix . $this->_text['upload_ext'] . $this->_sufix;
            }
        }
        return true;
    }

    private function _checkMaxSize($files)
    {
        if (is_array($files['size'])) {
            foreach ($files['size'] as $size) {
                if ($size > $this->_maxFileSize) {
                    return $this->_prefix . $this->_text['upload_max_size'] . $this->_sufix;
                }

                if ($size == 0) {
                    return $this->_prefix . $this->_text['upload_empty'] . $this->_sufix;
                }
            }
        } else {
            if ($files['size'] > $this->_maxFileSize) {
                return $this->_prefix . $this->_text['upload_max_size'] . $this->_sufix;
            }

            if ($files['size'] == 0) {
                return $this->_prefix . $this->_text['upload_empty'] . $this->_sufix;
            }
        }
        return true;
    }

    private function _uploadFile($files)
    {
        $_SESSION['image'] = time();

        if (is_array($files['size'])) {
            foreach ($files['name'] as $index => $name) {
                $uploadFile = $this->_uploadPath . $this->_pictureName($name);

                if (!move_uploaded_file($files['tmp_name'][$index], $uploadFile)) {
                    return $this->_prefix . $this->_text['upload_errors'] . $this->_sufix;
                }
            }
        } else {
           $uploadFile = $this->_uploadPath . $this->_pictureName($files['name']);

            if (!move_uploaded_file($files['tmp_name'], $uploadFile)) {
                return $this->_prefix . $this->_text['upload_errors'] . $this->_sufix;
            }
        }
        return true;
    }

}

/* end of file image.php */