<?php

namespace Model;
use \DB;

class Admin extends \Model
{

    public static function dashboard($userID)
    {
        $languages = DB::select('*')
                   ->from('languages')
                   ->execute();

        $language = DB::select('countries.*')
                 ->from('users_details')
                 ->join('users_settings')
                 ->on('users_settings.user_id', '=', 'users_details.user_id')
                 ->join('countries')
                 ->on('countries.country_id', '=', 'users_settings.country_id')
                 ->where('users_details.user_id', '=', $userID)
                 ->execute()
                 ->current();

        return array(
            'languages'     => count($languages),
            'users'         => self::contacts(),
            'language'      => $language,
            'partners'      => User::user_partners($userID),
            'now'           => User::user_now($userID),
            'subscribers'   => sizeof(Newsletter::subscribers($userID)),
            'companies'     => Company::companies($userID),
            'appoiments'    => Appointment::calendar($userID),
        );
    }

    public static function contacts()
    {
        $result = DB::select('*')
                   ->from('users')
                   ->execute();

        return count($result);
    }

    /* === USERS === */

    public static function users()
    {
        $query = DB::select('users.id', 'users.username', 'companies.company_name')
                 ->from('users')
                 ->join('companies', 'LEFT')
                 ->on('companies.user_id', '=', 'users.id')
                 ->where('users.group', '!=', 100)
                 ->execute();

        return $query->as_array();
    }

        /* === C.R.U.D. === */

        public static function delete_user($userID)
        {
            DB::delete('users')
                ->where('id', '=', $userID)
                ->execute();

            DB::delete('users_details')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('users_settings')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('users_socials')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('appointments')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('comments')
                ->where('user_id', '=', $userID)
                ->or_where('from_id', '=', $userID)
                ->execute();

            DB::delete('companies')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('images')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('like_page')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('messages')
                ->where('user_id', '=', $userID)
                ->or_where('message_from', '=', $userID)
                ->execute();

            DB::delete('newsletters')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('partners')
                ->where('user_id', '=', $userID)
                ->or_where('partner_id', '=', $userID)
                ->execute();

            DB::delete('subscribers')
                ->where('user_id', '=', $userID)
                ->execute();

            DB::delete('timeline')
                ->where('user_id', '=', $userID)
                ->execute();
        }

        /* === END C.R.U.D. === */
    /* === END USERS === */


    /* === CATEGORIES === */

    public static function categories()
    {
        $result = DB::select('*')
                   ->from('categories')
                   ->execute();

        return $result->as_array();
    }

    private static function category_by_id($category)
    {
        $result = DB::select('*')
                   ->from('categories')
                   ->where('category_name', '=', $category)
                   ->as_object()
                   ->execute()
                   ->current();

        return $result;
    }

        /* === C.R.U.D. === */

        public static function create_category($name)
        {
            $query = DB::insert('categories');
            $query->set(array(
                'category_id'      => null,
                'category_name'    => $name
            ));
            $query->execute();
        }

        public static function update_category($name, $categoryID)
        {
            DB::update('categories')
                ->value("category_name", $name)
                ->where('category_id', '=', $categoryID)
                ->execute();
        }

        public static function delete_category($categoryID)
        {
            DB::delete('categories')
                ->where('category_id', '=', $categoryID)
                ->execute();

            DB::delete('subcategories')
                ->where('category_id', '=', $categoryID)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END CATEGORIES === */


    /* === SUBCATEGORIES === */

    public static function subcategories()
    {
        $result = DB::select('*')
                   ->from('categories')
                   ->join('subcategories', 'LEFT')
                   ->on('categories.category_id', '=', 'subcategories.category_id')
                   ->execute();

        $categories = $result->as_array();

        $return = array();
        foreach ($categories as $cat)
        {
            $return[$cat['category_name']][$cat['subcategory_id']] = $cat['subcategory_name'];
        }

        return $return;
    }

        /* === C.R.U.D. === */

        public static function create_subcategory($category, $name)
        {
            $categoryID = self::category_by_id($category)->category_id;

            $query = DB::insert('subcategories');
            $query->set(array(
                'subcategory_id'    => null,
                'category_id'       => $categoryID,
                'subcategory_name'  => $name
            ));
            $query->execute();
        }

        public static function update_subcategory($name, $subcategoryID)
        {
            DB::update('subcategories')
                ->value("subcategory_name", $name)
                ->where('subcategory_id', '=', $subcategoryID)
                ->execute();
        }

        public static function delete_subcategory($subcategoryID)
        {
            DB::delete('subcategories')
                ->where('subcategory_id', '=', $subcategoryID)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END SUBCATEGORIES === */


    /* === SOCIALS === */

    public static function socials()
    {
        $result = DB::select('*')
                   ->from('socials')
                   ->execute();

        return $result->as_array();
    }

    private static function social_by_id($social)
    {
        $result = DB::select('*')
                   ->from('socials')
                   ->where('social_name', '=', $social)
                   ->as_object()
                   ->execute()
                   ->current();

        return $result;
    }

    /* === END SOCIALS === */


    /* === ACCOUNT === */

        /* === C.R.U.D. === */

        public static function update_account($values)
        {
            DB::update('users')
                ->value("user_name", $values['email'])
                ->value("email", $values['email'])
                ->value("password", $values['password'])
                ->where('id', '=', 1)
                ->where('group', '=', 100)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END ACCOUNT === */


    /* === LANGUAGES === */

    public static function countries()
    {
        $result = DB::select('*')
                   ->from('countries')
                   ->execute();

        return $result->as_array();
    }

    public static function country_by_id($country)
    {
        $result = DB::select('country_id')
                   ->from('countries')
                   ->where('country_name', '=', $country)
                   ->as_object()
                   ->execute()
                   ->current();

        return $result;
    }

    public static function languages()
    {
        $result = DB::select('*')
                   ->from('languages')
                   ->join('countries', 'LEFT')
                   ->on('countries.country_id', '=', 'languages.country_id')
                   ->execute();

        return $result->as_array();
    }

    public static function language($languageID)
    {
        $result = DB::select('*')
                   ->from('languages')
                   ->join('countries', 'LEFT')
                   ->on('countries.country_id', '=', 'languages.country_id')
                   ->where('languages.language_id', '=', $languageID)
                   ->execute()
                   ->current();

        return $result;
    }

        /* === C.R.U.D. === */

        public static function create_language($value)
        {
            $countryID = self::country_by_id($value)->country_id;

            $query = DB::insert('languages');
            $query->set(array(
                'language_id'   => null,
                'country_id'    => $countryID
            ));
            $query->execute();
        }

        public static function update_default_language($value)
        {
            DB::update('settings')
                ->value("settings_default_language", $value)
                ->where('settings_id', '=', 1)
                ->execute();
        }

        public static function delete_language($languageID)
        {
            DB::delete('languages')
                ->where('language_id', '=', $languageID)
                ->execute();
        }
        /* === C.R.U.D. === */
    /* === END LANGUAGES === */


    /* === SETTINGS === */

    public static function settings()
    {
        $result = DB::select('*')
                   ->from('settings')
                   ->where('settings_id', '=', 1)
                   ->execute()
                   ->current();

        $admin = User::user_by_id(1);

        return array(
            'app_name'      => $result['settings_app_name'],
            'app_language'  => $result['settings_default_language'],
            'app_power'     => $result['settings_power'],
            'app_email'     => $admin->email
        );
    }

        /* === C.R.U.D. === */

        public static function update_app($value)
        {
            $app = $value == 'single' ? 1 : 2;

            $query = DB::select('*')
                   ->from('settings')
                   ->where('settings_id', '=', 1)
                   ->execute()
                   ->current();

            if (count($query) == 0)
            {
                $query = DB::insert('settings');
                $query->set(array(
                    'settings_id'   => null,
                    'settings_app'  => $app
                ));
                $query->execute();
            }
            else
            {
                DB::update('settings')
                    ->value("settings_app", $app)
                    ->where('settings_id', '=', 1)
                    ->execute();
            }
        }

        public static function update_app_name($value)
        {
            DB::update('settings')
                ->value("settings_app_name", $value)
                ->where('settings_id', '=', 1)
                ->execute();
        }

        public static function update_power($value)
        {
            DB::update('settings')
                ->value("settings_power", $value)
                ->where('settings_id', '=', 1)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END SETTINGS === */

}