<?php

namespace Model;
use \DB;

class Appointment extends \Model
{

    public static function appointments($userID)
    {
        $query = DB::select('*')
                 ->from('appointments')
                 ->join('companies', 'LEFT')
                 ->on('companies.company_id', '=', 'appointments.company_id')
                 ->where('appointments.user_id', '=', $userID)
                 ->order_by('appointments.appointment_startdate')
                 ->execute();

        return $query->as_array();
    }

    public static function appointment($appointmentID, $userID)
    {
        $query = DB::select('*')
                 ->from('appointments')
                 ->join('companies', 'LEFT')
                 ->on('companies.company_id', '=', 'appointments.company_id')
                 ->join('subcategories')
                 ->on('subcategories.subcategory_id', '=', 'companies.subcategory_id')
                 ->join('categories')
                 ->on('categories.category_id', '=', 'subcategories.category_id')
                 ->where('appointments.user_id', '=', $userID)
                 ->where('appointments.appointment_id', '=', $appointmentID)
                 ->execute()
                 ->current();

        return $query;
    }

    public static function calendar($userID)
    {
        $appointments   = self::appointments($userID);
        $end            = end($appointments);
        $appointment    = "[";

        foreach ($appointments as $a)
        {
            if($a['appointment_status'] != 1)
            {
                $startDate  = explode('-', $a['appointment_startdate']);
                $startMonth = (int)$startDate[1] - 1;


                $appointment .=	"{ ";
                $appointment .= "title: '" . $a['appointment_subject'] . "', ";

                if ($a['appointment_starttime'])
                {
                    $startTime      = explode(':', $a['appointment_starttime']);
                    $appointment    .= "start: new Date($startDate[0], $startMonth, $startDate[2], $startTime[0], $startTime[1]) ";
                }
                else
                {
                    $appointment .= "start: new Date($startDate[0], $startMonth, $startDate[2]) ";
                }

                if($a['appointment_enddate'])
                {
                    $endDate        = explode('-', $a['appointment_enddate']);
                    $endMonth       = (int)$endDate[1] - 1;
                    $appointment    .= ", end: new Date($endDate[0], $endMonth, $endDate[2]) ";
                }
                elseif($a['appointment_enddate'] && $a['appointment_endtime'])
                {
                    $endDate        = explode('-', $a['appointment_enddate']);
                    $endMonth       = (int)$endDate[1] - 1;
                    $endTime        = explode(':', $a['appointment_endtime']);
                    $appointment    .= ", end: new Date($endDate[0], $endMonth, $endDate[2], $endTime[0], $endTime[1]) ";
                }
                elseif(!$a['appointment_enddate'] && $a['appointment_endtime'])
                {
                    $endTime        = explode(':', $a['appointment_endtime']);
                    $appointment    .= ", end: new Date($startDate[0], $startMonth, $startDate[2], $endTime[0], $endTime[1]) ";
                }

                $appointment .= ", allDay: false";

                if ($a['appointment_id'] != $end['appointment_id'])
                {
                    $appointment .= "}, ";
                }
                else
                {
                    $appointment .= "} ";
                }
            }
        }
        $appointment .= "]";

        return $appointment;
    }

        /* === C.R.U.D === */

        public static function create_appointment($values, $companyID, $userID)
        {
            DB::insert('appointments')
                ->set(array(
                        'appointment_id'        => null,
                        'user_id'               => $userID,
                        'company_id'            => $companyID,
                        'appointment_subject'   => $values['subject'],
                        'appointment_startdate' => $values['startDate'],
                        'appointment_starttime' => $values['startTime'] ? $values['startTime'] : null,
                        'appointment_enddate'   => $values['endDate'] ? $values['endDate'] : null,
                        'appointment_endtime'   => $values['endTime'] ? $values['endTime'] : null,
                        'appointment_obs'       => $values['obs'],
                        'appointment_status'    => 0
                    ))
                ->execute();
        }

        public static function update_appointment($values, $appointmentID, $userID)
        {
            DB::update('appointments')
                ->set(array(
                        'appointment_subject'   => $values['subject'],
                        'appointment_startdate' => $values['startDate'],
                        'appointment_starttime' => $values['startTime'] ? $values['startTime'] : null,
                        'appointment_enddate'   => $values['endDate'] ? $values['endDate'] : null,
                        'appointment_endtime'   => $values['endTime'] ? $values['endTime'] : null,
                        'appointment_obs'       => $values['obs'],
                    ))
                ->where('appointment_id', '=', $appointmentID)
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function complete_appointment($appointmentID, $userID)
        {
            DB::update('appointments')
                ->set(array(
                        'appointment_status'    => 1
                    ))
                ->where('appointment_id', '=', $appointmentID)
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function delete_appointment($appointmentID, $userID)
        {
            DB::delete('appointments')
                ->where('appointment_id', '=', $appointmentID)
                ->where('user_id', '=', $userID)
                ->execute();
        }
        /* === END C.R.U.D === */

}