<?php

namespace Model;
use \DB;

class Timeline extends \Model
{

    public static function timeline($userID)
    {
        $timeline = DB::select('*', DB::expr('TIMEDIFF(NOW(), timeline.timeline_date) as ago'))
                 ->from('timeline')
                 ->where('user_id', '=', $userID)
                 ->order_by('timeline_date', 'desc')
                 ->execute();

        $comments = DB::select('*', DB::expr('TIMEDIFF(NOW(), comment_date) as ago'))
                 ->from('comments')
                 ->join('users_details', 'LEFT')
                 ->on('users_details.user_id', '=', 'comments.from_id')
                 ->join('images', 'LEFT')
                 ->on('images.user_id', '=', 'users_details.user_id')
                 ->where('comments.user_id', '=', $userID)
                 ->where('images.image_type', '=', 1)
                 ->order_by('comments.comment_date', 'asc')
                 ->execute();

        return array(
            'timeline'  => $timeline->as_array(),
            'comments'  => $comments->as_array(),
        );
    }

    public static function one($timelineID, $userID)
    {
        $query = DB::select('*')
                 ->from('timeline')
                 ->where('timeline_id', '=', $timelineID)
                 ->where('user_id', '=', $userID)
                 ->execute()
                 ->current();

        return $query;
    }

    public static function details($timelineID, $userID)
    {
        $timeline = DB::select('*', DB::expr('TIMEDIFF(NOW(), timeline_date) as ago'))
                 ->from('timeline')
                 ->where('timeline_id', '=', $timelineID)
                 ->where('user_id', '=', $userID)
                 ->execute()
                 ->current();

        $comments = DB::select('*', DB::expr('TIMEDIFF(NOW(), comment_date) as ago'))
                 ->from('comments')
                 ->join('users_details', 'LEFT')
                 ->on('users_details.user_id', '=', 'comments.from_id')
                 ->join('images', 'LEFT')
                 ->on('images.user_id', '=', 'users_details.user_id')
                 ->where('comments.user_id', '=', $userID)
                 ->where('comments.timeline_id', '=', $timelineID)
                 ->where('images.image_type', '=', 1)
                 ->order_by('comments.comment_date', 'asc')
                 ->execute();

        return array(
            'timeline'  => $timeline,
            'comments'  => $comments->as_array(),
        );
    }

        /* === C.R.U.D. === */
        public static function create_timeline($values, $userID)
        {
            DB::insert('timeline')
                ->set(array(
                        'timeline_id'       => null,
                        'user_id'           => $userID,
                        'timeline_title'    => $values['title'],
                        'timeline_text'     => $values['text'],
                        'timeline_date'     => date('Y-m-d H:i:s')
                    ))
                ->execute();
        }

        public static function update_timeline($values, $timelineID, $userID)
        {
            DB::update('timeline')
                ->set(array(
                        'timeline_title'    => $values['title'],
                        'timeline_text'     => $values['text'],
                    ))
                ->where('timeline_id', '=', $timelineID)
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function delete_timeline($timelineID, $userID)
        {
            DB::delete('timeline')
                ->where('timeline_id', '=', $timelineID)
                ->where('user_id', '=', $userID)
                ->execute();
        }
        /* === END C.R.U.D. === */


    /* === COMMENTS === */

        /* === C.R.U.D. === */

        public static function create_comment($timelineID, $userID, $fromID, $text)
        {
            list($lastInsertID, $rows_affected) = DB::insert('comments')
                ->set(array(
                        'comment_id'        => null,
                        'timeline_id'       => $timelineID,
                        'user_id'           => $userID,
                        'from_id'           => $fromID,
                        'comment_text'      => $text,
                        'comment_date'      => date('Y-m-d H:i:s'),
                        'comment_status'    => 1
                    ))
                ->execute();

            $query = DB::select('*', DB::expr('TIMEDIFF(NOW(), comment_date) as ago'))
                     ->from('comments')
                     ->join('users_details', 'LEFT')
                     ->on('users_details.user_id', '=', 'comments.from_id')
                     ->join('images', 'LEFT')
                     ->on('images.user_id', '=', 'users_details.user_id')
                     ->where('comments.comment_id', '=', $lastInsertID)
                     ->where('comments.timeline_id', '=', $timelineID)
                     ->where('comments.user_id', '=', $userID)
                     ->where('images.image_type', '=', 1)
                     ->execute()
                     ->current();

            return $query;
        }

        public static function update_comment($values, $timelineID, $commentID, $fromID)
        {
           DB::update('comments')
                ->set(array(
                        'comment_text'  => $values,
                    ))
                ->where('comment_id', '=', $commentID)
                ->where('timeline_id', '=', $timelineID)
                ->where('from_id', '=', $fromID)
                ->execute();
        }

        public static function delete_comment($commentID, $userID)
        {
            DB::delete('comments')
                ->where('comment_id', '=', $commentID)
                ->where('from_id', '=', $userID)
                ->execute();
        }

        /* === END C.R.U.D. === */
    /* === END COMMENTS === */
}