<?php

namespace Model;
use \DB;

class User extends \Model
{

    public static function dashboard($userID)
    {
        $language = DB::select('countries.*')
                 ->from('users_details')
                 ->join('users_settings')
                 ->on('users_settings.user_id', '=', 'users_details.user_id')
                 ->join('countries')
                 ->on('countries.country_id', '=', 'users_settings.country_id')
                 ->where('users_details.user_id', '=', $userID)
                 ->execute()
                 ->current();

        return array(
            'language'      => $language,
            'partners'      => self::user_partners($userID),
            'now'           => self::user_now($userID),
            'subscribers'   => sizeof(Newsletter::subscribers($userID)),
            'companies'     => Company::companies($userID),
            'appoiments'    => Appointment::calendar($userID),
        );
    }

    /* === WALL === */

    public static function wall($userID)
    {
        $query = DB::query("SELECT partner_id as partner
                                FROM `partners`
                                WHERE user_id = " . $userID . "
                                AND  status = 1
                            UNION
                            SELECT user_id as partner
                                FROM `partners`
                                WHERE partner_id = " . $userID . "
                                AND status = 1 ");
        $partners = $query->execute()->as_array(null, 'partner');

        if ($partners)
        {
            $query = DB::query("SELECT users_details_A.company_name company1, users_details_B.company_name company2, users_details_A.company_url company1Url, users_details_B.company_url company2Url,
                                    partners.pdate timeline_date, TIMEDIFF(NOW(), partners.pdate) as ago
                                    FROM `partners`
                                    JOIN users_details users_details_A ON users_details_A.user_id = partners.user_id
                                    JOIN users_details users_details_B ON users_details_B.user_id = partners.partner_id
                                    WHERE partners.user_id IN (" . implode(", ", $partners) . ")
                                    AND partners.status = 1
                                UNION
                                SELECT users_details_A.company_name company1, users_details_B.company_name company2, users_details_A.company_url company1Url, users_details_B.company_url company2Url,
                                    partners.pdate timeline_date, TIMEDIFF(NOW(), partners.pdate) as ago
                                    FROM `partners`
                                    JOIN users_details users_details_A ON users_details_A.user_id = partners.user_id
                                    JOIN users_details users_details_B ON users_details_B.user_id = partners.partner_id
                                    WHERE partners.partner_id IN (" . implode(", ", $partners). ")
                                    AND partners.status = 1 ");
            $becamePartners = $query->execute()->as_array();

            $timeline = DB::select('users_details.company_name', 'users_details.company_url', 'timeline.*', 'images.*', DB::expr('TIMEDIFF(NOW(), timeline.timeline_date) as ago'))
                     ->from('users_details')
                     ->join('timeline', 'LEFT')
                     ->on('timeline.user_id', '=', 'users_details.user_id')
                     ->join('images', 'LEFT')
                     ->on('images.user_id', '=', 'users_details.user_id')
                     ->where('users_details.user_id', 'in', $partners)
                     ->where('images.image_type', '=', 1)
                     ->where('timeline.user_id', '!=', null)
                     ->where('users_details.user_status', '=', 1)
                     ->order_by('timeline.timeline_date', 'desc')
                     ->execute();

            $comments = DB::select('*', DB::expr('TIMEDIFF(NOW(), comment_date) as ago'))
                     ->from('comments')
                     ->join('users_details', 'LEFT')
                     ->on('users_details.user_id', '=', 'comments.from_id')
                     ->join('images', 'LEFT')
                     ->on('images.user_id', '=', 'users_details.user_id')
                     ->where('comments.user_id', 'in', $partners)
                     ->where('images.image_type', '=', 1)
                     ->order_by('comments.comment_date', 'asc')
                     ->execute();

            $wall = array_merge($timeline->as_array(), $becamePartners);

            foreach ($wall as $key => $part) {
                $sort[$key] = strtotime($part['timeline_date']);
            }
            array_multisort($sort, SORT_DESC, $wall);

            return array(
                'timeline'  => $wall,
                'comments'  => $comments->as_array(),
            );
        }

        return false;
    }

    /* === END WALL === */


    /* === USERS ===  */

    public static function user_now($userID)
    {
        $requests = DB::select('*')
                   ->from('partners')
                   ->where('partner_id', '=', $userID)
                   ->where('status', '=', 0)
                   ->execute();

        $messages = DB::select('*')
                   ->from('messages')
                   ->where('user_id', '=', $userID)
                   ->where('message_status', '=', 0)
                   ->execute();

        return array (
            'requests'      => count($requests),
            'messages'      => count($messages),
            'appointments'  => sizeof(Appointment::appointments($userID))
        );
    }

    public static function user_all_requests($userID)
    {
        $result = DB::select('*')
                   ->from('partners')
                   ->join('users_details', 'LEFT')
                   ->on('users_details.user_id', '=', 'partners.user_id')
                   ->join('subcategories', 'LEFT')
                   ->on('subcategories.subcategory_id', '=', 'users_details.subcategory_id')
                   ->join('categories', 'LEFT')
                   ->on('categories.category_id', '=', 'subcategories.category_id')
                   ->where('partner_id', '=', $userID)
                   ->where('status', '=', 0)
                   ->execute();

        return $result->as_array();
    }

    public static function user_by_id($userID)
    {
        $query = DB::select('*')
                 ->from('users')
                 ->join('users_details')
                 ->on('users_details.user_id', '=', 'users.id')
                 ->where('users.id', '=', $userID)
                 ->as_object()
                 ->execute()
                 ->current();

        return $query;
    }

    public static function user_by_email($email)
    {
        $query = DB::select('*')
                 ->from('users')
                 ->where('users.email', '=', $email)
                 ->as_object()
                 ->execute()
                 ->current();

        return $query;
    }

    public static function user_by_name($user)
    {
        $query = DB::select('user_id')
                 ->from('users_details')
                 ->where('company_name', '=', $user)
                 ->as_object()
                 ->execute()
                 ->current();

        return $query;
    }

    public static function user_by_url($user)
    {
        $query = DB::select('user_id')
                 ->from('users_details')
                 ->where('company_url', '=', $user)
                 ->as_object()
                 ->execute()
                 ->current();

        return $query;
    }

    public static function user_business($userID)
    {
        $query = DB::select('*')
                 ->from('users_details')
                 ->join('subcategories', 'LEFT')
                 ->on('subcategories.subcategory_id', '=', 'users_details.subcategory_id')
                 ->join('categories', 'LEFT')
                 ->on('categories.category_id', '=', 'subcategories.category_id')
                 ->where('user_id', '=', $userID)
                 ->execute()
                 ->current();

        return $query;
    }

    public static function business_category($userID)
    {
        $query = DB::select('subcategories.subcategory_id', 'subcategories.subcategory_name')
                 ->from('users_details')
                 ->join('subcategories')
                 ->on('subcategories.subcategory_id', '=', 'users_details.subcategory_id')
                 ->where('users_details.user_id', '=', $userID)
                 ->execute()
                 ->current();

        return $query;
    }

        /* === C.R.U.D. === */
        public static function create_user($userID)
        {
            DB::insert('users_details')
                ->set(array(
                        'user_id'               => $userID,
                        'lostpassword_hash'     => null,
                        'lostpassword_created'  => null,
                    ))
                ->execute();

            DB::insert('users_settings')
                ->set(array(
                        'user_id'   => $userID,
                    ))
                ->execute();

            DB::insert('images')
                ->set(array(
                        'image_id'      => null,
                        'user_id'       => $userID,
                        'image_name'    => '_logo.png',
                        'image_type'    => 1
                    ))
                ->execute();
        }

        public static function update_user($values, $userID)
        {
            DB::update('users_details')
                ->set(array(
                    'lostpassword_hash'     => $values['lostpassword_hash'],
                    'lostpassword_created'  => $values['lostpassword_created']
                ))
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function update_business($values, $userID)
        {
            DB::update('users_details')
                ->set(array(
                        'subcategory_id'        => $values['category'],
                        'company_name'          => $values['name'],
                        'company_country'       => $values['country'],
                        'company_state'         => $values['state'],
                        'company_city'          => $values['city'],
                        'company_zip_code'      => $values['zip'],
                        'company_address'       => $values['address'],
                        'company_phone'         => $values['phone'],
                        'company_email'         => $values['email'],
                        'company_website'       => $values['website'],
                        'company_description'   => $values['description']
                    ))
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function update_page_name($pageName, $userID)
        {
            DB::update('users_details')
                ->set(array(
                        'company_name'  => $pageName,
                        'company_url'   => $pageName,
                        'user_status'   => 1,
                    ))
                ->where('user_id', '=', $userID)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END USERS ===  */


    /* === SLIDERS, LOGO, PORTOFOLIO === */

    public static function user_slider_logo($userID)
    {
        $logo = DB::select('*')
                   ->from('images')
                   ->where('user_id', '=', $userID)
                   ->where('image_type', '=', '1')
                   ->execute()
                   ->current();

        $result = DB::select('*')
                   ->from('images')
                   ->where('user_id', '=', $userID)
                   ->where('image_type', '=', '2')
                   ->execute();

        return array(
            'logo'      => $logo,
            'sliders'   => $result->as_array()
        );
    }

    public static function user_portfolio($userID)
    {
        $result = DB::select('*')
                   ->from('images')
                   ->where('user_id', '=', $userID)
                   ->where('image_type', '=', '3')
                   ->execute();

        return $result->as_array();
    }

    public static function upload_image($image, $userID, $type)
    {
        if ($type != 1)
        {
            DB::insert('images')
                ->set(array(
                        'image_id'      => null,
                        'user_id'       => $userID,
                        'image_name'    => $image,
                        'image_type'    => $type
                    ))
                ->execute();
        }
        else
        {
            DB::update('images')
                ->set(array(
                        'image_name'    => $image
                    ))
                ->where('user_id', '=', $userID)
                ->where('image_type', '=', 1)
                ->execute();
        }
    }

    public static function delete_image($userID, $imageID)
    {
        $image = DB::select('*')
                   ->from('images')
                   ->where('user_id', '=', $userID)
                   ->where('image_id', '=', $imageID)
                   ->execute()
                   ->current();

        if ($image['image_type'] == 2)
        {
            unlink(DOCROOT . DS . 'public/upload/slider/' . $image['image_name']);
        }

        if ($image['image_type'] == 3)
        {
            unlink(DOCROOT . DS . 'public/upload/portfolio/' . $image['image_name']);
            unlink(DOCROOT . DS . 'public/upload/portfolio/thumbs/' . $image['image_name']);
        }

        DB::delete('images')
            ->where('user_id', '=', $userID)
            ->where('image_id', '=', $imageID)
            ->execute();
    }

    /* === END SLIDERS, LOGO, PORTOFOLIO === */


    /* === SOCIALS === */

    public static function user_socials($userID)
    {
        $result = DB::select('*')
                   ->from('socials')
                   ->execute();
        $socials = $result->as_array();

        $result = DB::select('*')
                   ->from('users_socials')
                   ->where('user_id', '=', $userID)
                   ->execute();
        $userSocials = $result->as_array();

        foreach ($socials as $k => $s)
        {
            foreach ($userSocials as $u)
            {
                if ($s['social_id'] == $u['social_id'])
                {
                    $socials[$k]['social_link'] = $u['social_link'];
                }
            }
        }

        return $socials;
    }

        /* === C.R.U.D. === */
        public static function create_social($link, $socialID, $userID)
        {
            $query = DB::select('*')
                   ->from('socials')
                   ->join('users_socials','LEFT')
                   ->on('users_socials.social_id', '=', 'socials.social_id')
                   ->where('socials.social_id', '=', $socialID)
                   ->where('users_socials.user_id', '=', $userID)
                   ->execute()
                   ->current();

            if ($query['social_id'])
            {
                DB::update('users_socials')
                    ->set(array(
                            'social_link' => $link,
                        ))
                    ->where('social_id', '=', $socialID)
                    ->where('user_id', '=', $userID)
                    ->execute();
            }
            else
            {
                DB::insert('users_socials')
                    ->set(array(
                            'id'            => null,
                            'user_id'       => $userID,
                            'social_id'     => $socialID,
                            'social_link'   => $link,
                        ))
                    ->execute();
            }
        }
        /* === END C.R.U.D. === */
    /* === SOCIALS === */


    /* === PARTNERS === */

    public static function user_partners($userID)
    {
        $query = DB::query("SELECT partner_id as partner
                    FROM `partners`
                    WHERE user_id = " . $userID . "
                    AND  status = 1
                    UNION
                    SELECT user_id as partner FROM `partners`
                    WHERE partner_id = " . $userID . " AND status = 1 ");
        $partners = $query->execute()->as_array();

        if ($partners)
        {
            $result = DB::select('*')
                       ->from('users_details')
                       ->join('subcategories', 'LEFT')
                       ->on('subcategories.subcategory_id', '=', 'users_details.subcategory_id')
                       ->join('categories', 'LEFT')
                       ->on('categories.category_id', '=', 'subcategories.category_id')
                       ->join('images', 'LEFT')
                       ->on('images.user_id', '=', 'users_details.user_id')
                       ->where('users_details.user_id', 'in', $partners)
                       ->where('images.image_type', '=', 1)
                       ->execute();

            return $result->as_array();
        }

        return false;
    }

    public static function user_partner_status($partnerID, $userID)
    {
        $q1 = DB::select('*')
                   ->from('partners')
                   ->where('user_id', '=', $userID)
                   ->where('partner_id', '=', $partnerID)
                   ->execute()
                   ->current();

        $q2 = DB::select('*')
                   ->from('partners')
                   ->where('user_id', '=', $partnerID)
                   ->where('partner_id', '=', $userID)
                   ->execute()
                   ->current();

        return array(
            'send'      => isset($q1['status']) ? $q1['status'] : 2,
            'receive'   => isset($q2['status']) ? $q2['status'] : 2
        );
    }

        /* === C.R.U.D. === */
        public static function create_partner($partnerID, $userID)
        {
            DB::insert('partners')
                ->set(array(
                        'id'            => null,
                        'user_id'       => $userID,
                        'partner_id'    => $partnerID,
                        'status'        => 0,
                        'pdate'         => date('Y-m-d H:i:s')
                    ))
                ->execute();
        }

        public static function accept_partner($partnerID, $userID)
        {
            DB::update('partners')
                ->set(array(
                        'status'    => 1,
                        'pdate'     => date('Y-m-d H:i:s')
                    ))
                ->where('user_id', '=', $partnerID)
                ->where('partner_id', '=', $userID)
                ->execute();
        }

        public static function cancel_partner($partnerID, $userID)
        {
            DB::delete('partners')
                ->where('user_id', '=', $userID)
                ->where('partner_id', '=', $partnerID)
                ->execute();
        }

        public static function delete_partner($partnerID, $userID)
        {
            DB::delete('partners')
                ->where('user_id', '=', $partnerID)
                ->where('partner_id', '=', $userID)
                ->execute();
        }
        /* === END C.R.U.D. === */
    /* === END PARTNERS === */


    /* === SEARCH === */

    public static function search($search)
    {
        $result = DB::select('users_details.user_id','users_details.company_name', 'images.image_name', 'users_details.company_url')
                   ->from('users_details')
                   ->join('images', 'LEFT')
                   ->on('images.user_id', '=', 'users_details.user_id')
                   ->where('company_name', 'like', '%' . $search . '%')
                   ->where('images.image_type', '=', 1)
                   ->execute();

        return $result->as_array();
    }

    /* === END SEARCH === */


    /* === PAGE === */

    public static function check_page_name($pageName, $userID)
    {
        $result = DB::select('user_id')
                   ->from('users_details')
                   ->where('company_url', '=', $pageName)
                   ->execute()
                   ->current();

        return array(
            'results'   => count($result),
            'user'      => $result['user_id'] == $userID ? true : false
        );
    }

    /* === END PAGE === */


    /* === SETTINGS === */

    public static function user_settings($userID, $all)
    {
        if (!$all)
        {
            $query = DB::select(array('users_details.user_id', 'userID'), 'users_details.company_name', 'users_details.company_url', 'users_details.user_status', 'users_settings.*', 'countries.country_name')
                 ->from('users_details')
                 ->join('users_settings', 'LEFT')
                 ->on('users_settings.user_id', '=', 'users_details.user_id')
                 ->join('countries', 'LEFT')
                 ->on('countries.country_id', '=', 'users_settings.country_id')
                 ->where('users_details.user_id', '=', $userID)
                 ->execute()
                 ->current();
        }
        else
        {
            $query = DB::select('users_details.company_name', 'users_details.company_url', 'users_details.user_status', 'users_settings.*')
                 ->from('users_details')
                 ->join('users_settings', 'LEFT')
                 ->on('users_settings.user_id', '=', 'users_details.user_id')
                 ->where('users_details.user_id', '=', $userID)
                 ->execute()
                 ->current();
        }

        return $query;
    }

    private static function language_by_name($country)
    {
        $query = DB::select('countries.country_id')
                 ->from('languages')
                 ->join('countries', 'LEFT')
                 ->on('countries.country_id', '=', 'languages.country_id')
                 ->where('countries.country_name', '=', $country)
                 ->as_object()
                 ->execute()
                 ->current();

        return $query->country_id;
    }

        /* === C.R.U.D. === */

        public static function update_user_language($country, $userID)
        {
            $countryID = self::language_by_name($country);

            DB::update('users_settings')
                ->set(array(
                        'country_id' => $countryID,
                    ))
                ->where('user_id', '=', $userID)
                ->execute();
        }

        public static function update_user_privacy($values, $userID)
        {
            DB::update('users_settings')
                ->set(array(
                        'show_country'      => $values['country'] == 'private' ? 1 : 0,
                        'show_state'        => $values['state'] == 'private' ? 1 : 0,
                        'show_city'         => $values['city'] == 'private' ? 1 : 0,
                        'show_zip_code'     => $values['code'] == 'private' ? 1 : 0,
                        'show_address'      => $values['address'] == 'private' ? 1 : 0,
                        'show_phone'        => $values['phone'] == 'private' ? 1 : 0,
                        'show_email'        => $values['email'] == 'private' ? 1 : 0,
                        'show_website'      => $values['website'] == 'private' ? 1 : 0,
                        'show_timeline'     => $values['timeline'] == 'private' ? 1 : 0,
                        'show_portfolio'    => $values['portfolio'] == 'private' ? 1 : 0,
                        'show_partners'     => $values['partners'] == 'private' ? 1 : 0
                    ))
                ->where('user_id', '=', $userID)
                ->execute();
        }
        /* === END C.R.U.D. === */

    /* === END SETTINGS === */


    /* === LIKE === */

    public static function likes($userID)
    {
        $query = DB::select('*')
                   ->from('like_page')
                   ->where('user_id', '=', $userID)
                   ->execute();

        return count($query);
    }

        /* === C.R.U.D === */
        public static function create_like($userID, $fromID)
        {
            $query = DB::select('*')
                       ->from('like_page')
                       ->where('user_id', '=', $userID)
                       ->where('from_id', '=', $fromID)
                       ->execute();

            if ( count($query) == 0 )
            {
                DB::insert('like_page')
                    ->set(array(
                            'like_id'   => null,
                            'user_id'   => $userID,
                            'from_id'   => $fromID,
                            'like_date' => date('Y-m-d')
                        ))
                    ->execute();
            }
            return false;
        }

        /* === C.R.U.D === */

    /* === END LIKE === */
}

















